@@ -22,8 +22,8 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef MESSAGECOMPSER_SIGNATURECONTROLLER_H
-#define MESSAGECOMPSER_SIGNATURECONTROLLER_H
+#ifndef MESSAGECOMPOSER_SIGNATURECONTROLLER_H
+#define MESSAGECOMPOSER_SIGNATURECONTROLLER_H
 
 #include "messagecomposer_export.h"
 #include <QObject>
@@ -35,12 +35,13 @@ class IdentityCombo;
 
 namespace MessageComposer {
 class RichTextComposerNg;
-
-/** Controls signature (the footer thing, not the crypto thing) operations
+class SignatureControllerPrivate;
+/**
+ * @brief The SignatureController class
+ * Controls signature (the footer thing, not the crypto thing) operations
  *  happening on a KMEditor triggered by identity selection or menu actions.
  *  @since 4.5
  */
-class SignatureControllerPrivate;
 class MESSAGECOMPOSER_EXPORT SignatureController : public QObject
 {
     Q_OBJECT
