@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,7 +26,10 @@
 namespace MessageComposer {
 class PluginEditorCheckBeforeSendPrivate;
 class PluginEditorCheckBeforeSendInterface;
-
+/**
+ * @brief The PluginEditorCheckBeforeSend class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MESSAGECOMPOSER_EXPORT PluginEditorCheckBeforeSend : public QObject
 {
     Q_OBJECT
@@ -36,16 +39,16 @@ public:
 
     virtual PluginEditorCheckBeforeSendInterface *createInterface(QObject *parent) = 0;
 
-    virtual bool hasConfigureDialog() const;
+    Q_REQUIRED_RESULT virtual bool hasConfigureDialog() const;
 
     virtual void showConfigureDialog(QWidget *parent = nullptr);
 
     void emitConfigChanged();
 
-    virtual QString description() const;
+    Q_REQUIRED_RESULT virtual QString description() const;
 
     void setIsEnabled(bool enabled);
-    bool isEnabled() const;
+    Q_REQUIRED_RESULT bool isEnabled() const;
 
 Q_SIGNALS:
     void configChanged();
