@@ -214,8 +214,8 @@ bool Util::saveContents(QWidget *parent, const KMime::Content::List &contents, Q
                 file = origFile;
                 int num = renameNumbering[file] + 1;
                 int dotIdx = file.lastIndexOf(QLatin1Char('.'));
-                file = file.insert((dotIdx >= 0) ? dotIdx : file.length(), QLatin1Char(
-                                       '_') + QString::number(num));
+                file.insert((dotIdx >= 0) ? dotIdx : file.length(), QLatin1Char(
+                                '_') + QString::number(num));
             }
             curUrl = curUrl.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash);
             curUrl.setPath(curUrl.path() + QLatin1Char('/') + file);
