@@ -17,25 +17,20 @@
    02110-1301, USA.
 */
 
-#ifndef __MIMETREEPARSER_BODYFORAMATTER_MULTIPARTENCRYPTED_H__
-#define __MIMETREEPARSER_BODYFORAMATTER_MULTIPARTENCRYPTED_H__
+#ifndef MIMETREEPARSER_BODYFORAMATTER_MULTIPARTENCRYPTED_H
+#define MIMETREEPARSER_BODYFORAMATTER_MULTIPARTENCRYPTED_H
 
 #include "interfaces/bodypartformatter.h"
 #include "interfaces/bodypart.h"
 
-namespace MimeTreeParser
-{
-
+namespace MimeTreeParser {
 class MultiPartEncryptedBodyPartFormatter : public Interface::BodyPartFormatter
 {
     static const MultiPartEncryptedBodyPartFormatter *self;
 public:
-    Interface::MessagePart::Ptr process(Interface::BodyPart &part) const override;
-    Interface::BodyPartFormatter::Result format(Interface::BodyPart *, HtmlWriter *) const override;
-    using Interface::BodyPartFormatter::format;
+    MessagePartPtr process(Interface::BodyPart &part) const override;
     static const Interface::BodyPartFormatter *create();
 };
-
 }
 
 #endif
